@@ -4,7 +4,8 @@
    implemented as a widget by Chris Cannam in Rosegarden,
    adapted for QSynth by Pedro Lopez-Cabanillas,
    improved for Qt4 by David Garcia Garzon,
-   adapted as a QStyle by Pedro Lopez-Cabanillas 
+   adapted as a QStyle by Pedro Lopez-Cabanillas,
+   updated for Qt5 by rncbc aka Rui Nuno Capela.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -71,7 +72,7 @@ qsynthDialVokiStyle::drawComplexControl(ComplexControl cc, const QStyleOptionCom
 	
 	QPalette pal = opt->palette;
 	QColor knobColor = pal.mid().color();
-	QColor borderColor = knobColor.light();
+	QColor borderColor = knobColor.lighter();
 	QColor meterColor = (dial->state & State_Enabled) ? 
 						pal.highlight().color() : pal.mid().color();   
 	QColor background = pal.window().color();
@@ -82,9 +83,9 @@ qsynthDialVokiStyle::drawComplexControl(ComplexControl cc, const QStyleOptionCom
 	// The bright metering bit...
 
 	QConicalGradient meterShadow(xcenter, ycenter, -90);
-	meterShadow.setColorAt(0, meterColor.dark());
+	meterShadow.setColorAt(0, meterColor.darker());
 	meterShadow.setColorAt(0.5, meterColor);
-	meterShadow.setColorAt(1.0, meterColor.light().light());
+	meterShadow.setColorAt(1.0, meterColor.lighter().lighter());
 	p->setBrush(meterShadow);
 	p->setPen(Qt::transparent);
 	p->drawPie(xcenter - meterWidth / 2, ycenter - meterWidth / 2,
@@ -111,9 +112,9 @@ qsynthDialVokiStyle::drawComplexControl(ComplexControl cc, const QStyleOptionCom
 	QRadialGradient gradient(
 		xcenter - shineCenter, ycenter - shineCenter,
 		shineExtension,	xcenter - shineFocus, ycenter - shineFocus);
-	gradient.setColorAt(0.2, knobColor.light().light());
+	gradient.setColorAt(0.2, knobColor.lighter().lighter());
 	gradient.setColorAt(0.5, knobColor);
-	gradient.setColorAt(1.0, knobColor.dark(150));
+	gradient.setColorAt(1.0, knobColor.darker(150));
 	QBrush knobBrush(gradient);
 	p->setBrush(knobBrush);
 	p->drawEllipse(xcenter - knobWidth / 2, ycenter - knobWidth / 2,
@@ -153,8 +154,8 @@ qsynthDialVokiStyle::drawComplexControl(ComplexControl cc, const QStyleOptionCom
 	if (knobBorderWidth > 0) {
 		QLinearGradient inShadow(xcenter - side / 4, ycenter - side / 4,
 			xcenter + side / 4, ycenter + side / 4);
-		inShadow.setColorAt(0.0, borderColor.light());
-		inShadow.setColorAt(1.0, borderColor.dark());
+		inShadow.setColorAt(0.0, borderColor.lighter());
+		inShadow.setColorAt(1.0, borderColor.darker());
 		p->setPen(QPen(QBrush(inShadow), knobBorderWidth * 7 / 8));
 		p->drawEllipse(xcenter - side / 2 + indent,
 			ycenter - side / 2 + indent,
@@ -164,8 +165,8 @@ qsynthDialVokiStyle::drawComplexControl(ComplexControl cc, const QStyleOptionCom
 	// Scale shadow...
 	QLinearGradient outShadow(xcenter - side / 3, ycenter - side / 3,
 		xcenter + side / 3, ycenter + side / 3);
-	outShadow.setColorAt(0.0, background.dark().dark());
-	outShadow.setColorAt(1.0, background.light().light());
+	outShadow.setColorAt(0.0, background.darker().darker());
+	outShadow.setColorAt(1.0, background.lighter().lighter());
 	p->setPen(QPen(QBrush(outShadow), scaleShadowWidth));
 	p->drawArc(xcenter - side / 2 + scaleShadowWidth / 2,
 		ycenter - side / 2 + scaleShadowWidth / 2,
@@ -180,11 +181,11 @@ qsynthDialVokiStyle::drawComplexControl(ComplexControl cc, const QStyleOptionCom
 	double y = ycenter + len * cos(angle);
 
 	QColor pointerColor = pal.dark().color();
-	pen.setColor((dial->state & State_Enabled) ? pointerColor.dark(140) : pointerColor);
+	pen.setColor((dial->state & State_Enabled) ? pointerColor.darker(140) : pointerColor);
 	pen.setWidth(pointerWidth + 2);
 	p->setPen(pen);
 	p->drawLine(QLineF(xcenter, ycenter, x, y));
-	pen.setColor((dial->state & State_Enabled) ? pointerColor.light() : pointerColor.light(140));
+	pen.setColor((dial->state & State_Enabled) ? pointerColor.lighter() : pointerColor.lighter(140));
 	pen.setWidth(pointerWidth);
 	p->setPen(pen);
 	p->drawLine(QLineF(xcenter - 1, ycenter - 1, x - 1, y - 1));
