@@ -56,11 +56,11 @@
 
 #include <QSessionManager>
 
-#if QT_VERSION >= 0x050000
+#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
 #include <QMimeData>
 #endif
 
-#if QT_VERSION < 0x040500
+#if QT_VERSION < QT_VERSION_CHECK(4, 5, 0)
 namespace Qt {
 const WindowFlags WindowCloseButtonHint = WindowFlags(0x08000000);
 }
@@ -2058,7 +2058,7 @@ void qsynthMainForm::stopEngine ( qsynthEngine *pEngine )
 			savePanelSettings(pEngine);
 		// Make those settings persist over...
 		m_pOptions->saveSetup(pSetup, pEngine->isDefault()
-			? QString::null : pEngine->name());
+			? QString() : pEngine->name());
 	}
 
 	// Flush anything that maybe pending...
