@@ -1,7 +1,7 @@
 // qsynthOptions.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2018, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -39,7 +39,7 @@ qsynthOptions::qsynthOptions (void)
 	// Create default setup descriptor.
 	m_pDefaultSetup = new qsynthSetup();
 	// Load previous/default fluidsynth settings...
-	loadSetup(m_pDefaultSetup, QString::null);
+	loadSetup(m_pDefaultSetup, QString());
 
 	loadOptions();
 }
@@ -205,11 +205,11 @@ void qsynthOptions::print_usage ( const QString& arg0 )
 		QObject::tr("Don't read commands from the shell [ignored]") + sEol;
 	out << "  -d, --dump" + sEot +
 		QObject::tr("Dump midi router events") + sEol;
-	out << "  -v, --verbose" + sEot +
+	out << "  -V, --verbose" + sEot +
 		QObject::tr("Print out verbose messages about midi events") + sEol;
 	out << "  -h, --help" + sEot +
 		QObject::tr("Show help about command line options") + sEol;
-	out << "  -V, --version" + sEot +
+	out << "  -v, --version" + sEot +
 		QObject::tr("Show version information") + sEol;
 }
 
@@ -358,14 +358,14 @@ bool qsynthOptions::parse_args ( const QStringList& args )
 		else if (sArg == "-d" || sArg == "--dump") {
 			m_pDefaultSetup->bMidiDump = true;
 		}
-		else if (sArg == "-v" || sArg == "--verbose") {
+		else if (sArg == "-V" || sArg == "--verbose") {
 			m_pDefaultSetup->bVerbose = true;
 		}
 		else if (sArg == "-h" || sArg == "--help") {
 			print_usage(args.at(0));
 			return false;
 		}
-		else if (sArg == "-V" || sArg == "--version") {
+		else if (sArg == "-v" || sArg == "--version") {
 			out << QString("Qt: %1\n")
 				.arg(qVersion());
 			out << QString("FluidSynth: %1\n")
@@ -384,7 +384,7 @@ bool qsynthOptions::parse_args ( const QStringList& args )
 					m_pDefaultSetup->bankoffsets.clear();
 				}
 				m_pDefaultSetup->soundfonts.append(name);
-				m_pDefaultSetup->bankoffsets.append(QString::null);
+				m_pDefaultSetup->bankoffsets.append(QString());
 			}
 			else if (::fluid_is_midifile(name)) {
 				m_pDefaultSetup->midifiles.append(name);
@@ -481,14 +481,20 @@ void qsynthOptions::loadSetup ( qsynthSetup *pSetup, const QString& sName )
 	m_settings.beginGroup("/Settings");
 	pSetup->sDisplayName     = m_settings.value("/DisplayName", sDisplayName).toString();
 	pSetup->bMidiIn          = m_settings.value("/MidiIn", true).toBool();
-#if defined(__WIN32__) || defined(_WIN32) || defined(WIN32)
+#if defined(__APPLE__)
+	pSetup->sMidiDriver      = m_settings.value("/MidiDriver", "coremidi").toString();
+	pSetup->sAudioDriver     = m_settings.value("/AudioDriver", "coreaudio").toString();
+#elif defined(__WIN32__) || defined(_WIN32) || defined(WIN32)
 	pSetup->sMidiDriver      = m_settings.value("/MidiDriver", "winmidi").toString();
 	pSetup->sAudioDriver     = m_settings.value("/AudioDriver", "dsound").toString();
-	pSetup->iAudioBufSize    = m_settings.value("/AudioBufSize", 512).toInt();
-	pSetup->iAudioBufCount   = m_settings.value("/AudioBufCount", 8).toInt();
 #else
 	pSetup->sMidiDriver      = m_settings.value("/MidiDriver", "alsa_seq").toString();
 	pSetup->sAudioDriver     = m_settings.value("/AudioDriver", "jack").toString();
+#endif
+#if defined(__WIN32__) || defined(_WIN32) || defined(WIN32)
+	pSetup->iAudioBufSize    = m_settings.value("/AudioBufSize", 512).toInt();
+	pSetup->iAudioBufCount   = m_settings.value("/AudioBufCount", 8).toInt();
+#else
 	pSetup->iAudioBufSize    = m_settings.value("/AudioBufSize", 64).toInt();
 	pSetup->iAudioBufCount   = m_settings.value("/AudioBufCount", 2).toInt();
 #endif
@@ -911,7 +917,7 @@ void qsynthOptions::loadWidgetGeometry ( QWidget *pWidget, bool bVisible )
 	if (pWidget) {
 	//	if (bVisible) pWidget->show(); -- force initial exposure?
 		m_settings.beginGroup("/Geometry/" + pWidget->objectName());
-	#if QT_VERSION >= 0x050000
+	#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
 		const QByteArray& geometry
 			= m_settings.value("/geometry").toByteArray();
 		if (!geometry.isEmpty())
@@ -948,7 +954,7 @@ void qsynthOptions::saveWidgetGeometry ( QWidget *pWidget, bool bVisible )
 	// only save the form geometry while its up and visible)
 	if (pWidget) {
 		m_settings.beginGroup("/Geometry/" + pWidget->objectName());
-	#if QT_VERSION >= 0x050000
+	#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
 		m_settings.setValue("/geometry", pWidget->saveGeometry());
 	#else//--SAVE_OLD_GEOMETRY
 		const QPoint& wpos  = pWidget->pos();
