@@ -1,7 +1,7 @@
 // qsynthSetupForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2018, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -165,8 +165,8 @@ static void qsynth_settings_foreach (
 	#endif
 		(pData->pListItem)->setText(iCol++, pszCurrent);
 		(pData->pListItem)->setText(iCol++, pszDefault);
-		(pData->pListItem)->setText(iCol++, QString::null);
-		(pData->pListItem)->setText(iCol++, QString::null);
+		(pData->pListItem)->setText(iCol++, QString());
+		(pData->pListItem)->setText(iCol++, QString());
 	#ifdef CONFIG_FLUID_SETTINGS_DUPSTR
 		::free(pszCurrent);
 	#endif
@@ -218,7 +218,7 @@ qsynthSetupForm::qsynthSetupForm (
 	QHeaderView *pHeader = m_ui.SoundFontListView->header();
 	pHeader->setDefaultAlignment(Qt::AlignLeft);
 //	pHeader->setDefaultSectionSize(300);
-#if QT_VERSION >= 0x050000
+#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
 //	pHeader->setSectionResizeMode(QHeaderView::Custom);
 	pHeader->setSectionsMovable(false);
 #else
@@ -235,7 +235,7 @@ qsynthSetupForm::qsynthSetupForm (
 	pHeader = m_ui.SettingsListView->header();
 	pHeader->setDefaultAlignment(Qt::AlignLeft);
 //	pHeader->setDefaultSectionSize(160);
-#if QT_VERSION >= 0x050000
+#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
 //	pHeader->setSectionResizeMode(QHeaderView::Custom);
 	pHeader->setSectionsMovable(false);
 #else
